@@ -27,9 +27,6 @@ FORM_FIELD_MAP = {
     'string': lambda label, f: StringField(l, get_field_validators(f))
 }
 
-class NexusForm(Form):
-    pass
-
 def get_field_validators(field_info):
     validator_list = []
     field_validators = field_info.get('validators', {})
@@ -88,7 +85,8 @@ def get_field_class(field_info):
     )
 
 def create_wtform_from_schema(schema):
-    NF = NexusForm
+    """class NexusForm(Form): pass"""
+    NF = type('NexusForm', (Form,), {})
     for field_name, field_info in schema.items():
         field_class = get_field_class(field_info)
         if field_class:
